==> opigno_lms-7.x-1.31-core.tar.gz: opigno_lms-7.x-1.31/profiles/opigno_lms/modules/contrib/h5p/modules/h5peditor/h5peditor/language/el.js <==
H5PEditor.language.core = {
  missingTranslation: '[Λείπει μετάφραση :key]',
  loading: 'Φόρτωση, παρακαλούμε περιμένετε...',
  selectLibrary: 'Επιλέξτε τη βιβλιοθήκη την οποία θέλετε να χρησιμοποιήσετε για το περιεχόμενό σας.',
  unknownFieldPath: 'Δεν είναι δυνατή η εύρεση του ":path".',
  notImageField: 'Το ":path" δεν είναι εικόνα.',
  notImageOrDimensionsField: 'Το ":path" δεν είναι εικόνα ή πεδίο διαστάσεων.',
  requiredProperty: 'Η ιδιότητα :property απαιτείται, και πρέπει να έχει μια τιμή.',
  onlyNumbers: 'Η τιμή της ιδιότητας :property μπορεί να περιέχει μόνο αριθμούς.',
  exceedsMax: 'Η τιμή της ιδιότητας :property υπερβαίνει το μέγιστο :max.',
  listExceedsMax: 'Ο κατάλογος υπερβαίνει το μέγιστο των :max στοιχείων.',
  belowMin: 'Η τιμή της ιδιότητας :property είναι μικρότερη από το ελάχιστο :min.',
  listBelowMin: 'Η λίστα χρειάζεται τουλάχιστον :min στοιχεία για να λειτουργεί σωστά το περιεχόμενο.',
  outOfStep: 'Η τιμή της ιδιότητας :property μπορεί να αλλάξει μόνο σε :step βήματα.',
  add: 'Προσθήκη',
  addFile: 'Προσθήκη αρχείου',
  removeFile: 'Αφαίρεση αρχείου',
  confirmRemoval: 'Είστε σίγουροι οτι επιθυμείτε να αφαιρέσετε το :type;',
  removeImage: 'Αφαίρεση εικόνας',
  confirmImageRemoval: 'Αυτή η ενέργεια θα αφαιρέσει την εικόνα σας. Είστε σίγουροι οτι θέλετε να προχωρήσετε;',
  changeFile: 'Αλλαγή αρχείου',
  changeLibrary: 'Αλλαγή τύπου περιεχομένου;',
  semanticsError: 'Σφάλμα σημασιολογίας: :error',
  missingProperty: 'Το πεδίο :index υπολείπεται της ιδιότητας :property.',
  expandCollapse: 'Ανάπτυξη/Σύμπτυξη',
  addEntity: 'Προσθήκη :entity',
  tooLong: 'Η τιμή του πεδίου είναι πολύ μεγάλη, πρέπει να περιέχει :max γράμματα ή λιγότερα.',
  invalidFormat: 'Η τιμή του πεδίου περιέχει μια μη έγκυρη μορφή ή χαρακτήρες οι οποίοι απαγορεύονται.',
  confirmChangeLibrary: 'Κάνοντας αυτό θα χάσετε όλη την εργασία που έχει γίνει με τον τρέχοντα τύπο περιεχομένου. Είστε βέβαιοι ότι θέλετε να αλλάξετε τύπο περιεχομένου;',
  commonFields: 'Παραλλαγές κειμένου και μεταφράσεις',
  commonFieldsDescription: 'Εδώ μπορείτε να επεξεργαστείτε ρυθμίσεις ή να μεταφράσετε κείμενα τα οποία χρησιμοποιούνται σε αυτό το περιεχόμενο.',
  uploading: 'Μεταφόρτωση, παρακαλούμε περιμένετε...',
  noFollow: 'Δεν είναι δυνατή η παρακολούθηση του πεδίου ":path".',
  editCopyright: 'Επεξεργασία πνευματικών δικαιωμάτων',
  close: 'Κλείσιμο',
  tutorial: 'Μάθημα',
  example: 'Παράδειγμα',
  editMode: 'Λειτουργία επεξεργασίας',
  listLabel: 'Λίστα',
  uploadError: 'Σφάλμα Μεταφόρτωσης Αρχείου',
  fileToLarge: 'Το αρχείο το οποίο προσπαθείτε να μεταφορτώσετε, ενδέχεται να είναι πολύ μεγάλο.',
  unknownFileUploadError: 'Άγνωστο σφάλμα μεταφόρτωσης αρχείου',
  noSemantics: 'Σφάλμα, δεν ήταν δυνατή η φόρτωση της φόρμας τύπου περιεχομένου.',
  editImage: 'Επεξεργασία εικόνας',
  saveLabel: 'Αποθήκευση',
  cancelLabel: 'ακύρωση',
  resetToOriginalLabel: 'Επαναφορά στο πρωτότυπο',
  loadingImageEditor: 'Φόρτωση επεξεργαστή εικόνας, παρακαλούμε περιμένετε...',
  selectFiletoUpload: 'Επιλέξτε αρχείο προς μεταφόρτωση',
  or: 'ή',
  enterAudioUrl: 'Εισαγάγετε διεύθυνση URL ήχου',
  enterVideoUrl: 'Εισαγάγετε διεύθυνση URL βίντεο ή σύνδεσμο YouTube',
  enterAudioTitle: 'Επικολλήστε σύνδεσμο ή άλλη διεύθυνση URL ήχου',
  enterVideoTitle: 'Επικολλήστε σύνδεσμο YouTube ή άλλη διεύθυνση URL βίντεο',
  uploadAudioTitle: 'Μεταφορτώστε αρχείο ήχου',
  uploadVideoTitle: 'Μεταφορτώστε αρχείο video',
  addVideoDescription: 'Το H5P υποστηρίζει όλες τις εξωτερικές πηγές βίντεο μορφοποιημένες ως mp4, webm ή ogv, όπως το Vimeo Pro, και έχει υποστήριξη για συνδέσμους YouTube.',
  insert: 'Εισαγωγή',
  cancel: 'Ακύρωση',
  height: 'ύψος',
  width: 'πλάτος',
  textField: 'πεδίο κειμένου',
  numberField: 'αριθμητικό πεδίο',
  orderItemUp: 'Ταξινόμηση στοιχείου προς τα επάνω',
  orderItemDown: 'Ταξινόμηση στοιχείου προς τα κάτω',
  removeItem: 'Αφαίρεση στοιχείου',
  hubPanelLabel: 'Επιλέξτε τύπο περιεχομένου',
  importantInstructions: 'Σημαντικές οδηγίες',
  showImportantInstructions: 'Εμφάνιση οδηγιών',
  hideImportantInstructions: 'Απόκρυψη σημαντικών οδηγιών',
  hide: 'Απόκρυψη',
  createContentTabLabel: 'Δημιουργία Περιεχομένου',
  uploadTabLabel: 'Μεταφόρτωση',
  uploadPlaceholder: 'Δεν έχει επιλεγεί αρχείο',
  uploadInstructionsTitle: 'Μεταφορτώστε ένα αρχείο H5P.',
  uploadInstructionsContent: 'Μπορείτε να ξεκινήσετε με παραδείγματα από το <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Μεταφόρτωση αρχείου',
  uploadFileButtonChangeLabel: 'Αλλαγή αρχείου',
  uploadingThrobber: 'Γίνεται μεταφόρτωση...',
  uploadSuccess: ':title was successfully uploaded!',
  unableToInterpretError: 'Unable to interpret response.',
  unableToInterpretSolution: 'Please check your error log.',
  h5pFileWrongExtensionTitle: 'Δεν ήταν δυνατή η μεταφόρτωση του επιλεγμένου αρχείου',
  h5pFileWrongExtensionContent: 'Μόνο αρχεία με επέκταση .h5p επιτρέπονται.',
  h5pFileValidationFailedTitle: 'Δεν ήταν δυνατή η επικύρωση του αρχείου H5P.',
  h5pFileValidationFailedContent: 'Βεβαιωθείτε ότι το φορτωμένο H5P περιέχει έγκυρο περιεχόμενο H5P. ' +
  'Τα αρχεία H5P τα οποία περιέχουν μόνο βιβλιοθήκες, θα πρέπει να μεταφορτωθούν μέσω της σελίδας Βιβλιοθήκες H5P.',
  h5pFileUploadServerErrorTitle: 'Δεν ήταν δυνατή η μεταφόρτωση του αρχείου H5P',
  h5pFileUploadServerErrorContent: 'Προέκυψε ένα μη αναμενόμενο σφάλμα. Ελέγξτε το αρχείο σφαλμάτων του διακομιστή σας για περισσότερες λεπτομέρειες.',
  contentTypeSectionAll: 'All Content Types',
  searchResults: 'Search Results',
  contentTypeSearchFieldPlaceholder: 'Αναζητήστε Τύπους Περιεχομένου',
  contentTypeInstallButtonLabel: 'Εγκατάσταση',
  contentTypeInstallingButtonLabel: 'Εγκατάσταση',
  contentTypeUseButtonLabel: 'Χρήση',
  contentTypeDetailButtonLabel: 'Details',
  contentTypeUpdateButtonLabel: 'Ενημέρωση',
  contentTypeUpdatingButtonLabel: 'Ενημέρωση',
  contentTypeGetButtonLabel: 'Λήψη',
  contentTypeBackButtonLabel: 'Πίσω',
  contentTypeIconAltText: 'Εικονίδιο',
  contentTypeInstallSuccess: ':contentType εγκαταστάθηκε με επιτυχία!',
  contentTypeUpdateSuccess: ':contentType ενημερώθηκε με επιτυχία!',
  contentTypeInstallError: ':contentType δεν ήταν δυνατόν να εγκατασταθεί. Επικοινωνήστε με το διαχειριστή σας.',
  contentTypeLicensePanelTitle: 'Άδεια',
  contentTypeDemoButtonLabel: 'Δείγμα Περιεχομένου',
  numResults: ':num results',
  show: 'Show',
  recentlyUsedFirst: 'Recently Used First',
  popularFirst: 'Popular First',
  newestFirst: 'Newest First',
  aToZ: 'A to Z',
  noResultsFound: 'No results found',
  noResultsFoundDesc: 'There is no content type that matches your search criteria.',
  readMore: 'Διαβάστε περισσότερα',
  readLess: 'Διαβάστε λιγότερα',
  contentTypeOwner: 'Από :owner',
  contentTypeUnsupportedApiVersionTitle: 'Αυτός ο τύπος περιεχομένου απαιτεί νεότερη έκδοση',
  contentTypeUnsupportedApiVersionContent: 'Επικοινωνήστε με το διαχειριστή του συστήματός σας, για την παροχή των απαραίτητων ενημερώσεων',
  contentTypeUpdateAvailable: 'Υπάρχει διαθέσιμη ενημέρωση',
  contentTypeRestricted: 'Περιορισμένος τύπος περιεχομένου',
  contentTypeRestrictedDesc: 'Η χρήση αυτού του τύπου περιεχομένου έχει περιοριστεί από τον διαχειριστή.',
  contentTypeNotInstalled: 'Ο τύπος περιεχομένου δεν εγκαταστάθηκε',
  contentTypeNotInstalledDesc: 'Δεν έχετε άδεια για την εγκατάσταση τύπων περιεχομένου.',
  theContentType: 'τον τύπο περιεχομένου',
  currentMenuSelected: 'τρέχουσα επιλογή',
  errorCommunicatingHubTitle: 'Δεν είναι σε θέση να επικοινωνήσει με το διανομέα.',
  errorCommunicatingHubContent: 'Παρουσιάστηκε σφάλμα. Παρακαλούμε προσπαθήστε ξανα.',
  warningNoContentTypesInstalled: 'Δεν έχετε εγκατεστημένους τύπους περιεχομένου.',
  warningChangeBrowsingToSeeResults: 'Κάντε κλικ στο κουμπί <em>Όλα</em> για να λάβετε τη λίστα με όλους τους τύπους περιεχομένου τους οποίους μπορείτε να εγκαταστήσετε.',
  warningUpdateAvailableTitle: 'Μια νέα έκδοση του :contentType είναι διαθέσιμη.',
  warningUpdateAvailableBody: 'Ενημερώστε στην τελευταία έκδοση για βελτιωμένη εμπειρία χρήσης.',
  licenseDescription: 'Ορισμένα από τα χαρακτηριστικά αυτής της άδειας αναφέρονται παρακάτω. Κάντε κλικ στο παραπάνω εικονίδιο πληροφοριών για να διαβάσετε το πρωτότυπο κείμενο της άδειας χρήσης.',
  licenseModalTitle: 'Λεπτομέρειες Άδειας Χρήσης',
  licenseModalSubtitle: 'Επιλέξτε μια άδεια χρήσης για να δείτε πληροφορίες σχετικά με τη σωστή χρήση',
  licenseUnspecified: 'Απροσδιόριστο',
  licenseCanUseCommercially: 'Μπορεί να χρησιμοποιηθεί για εμπορικό σκοπό',
  licenseCanModify: 'Μπορεί να τροποποιηθεί',
  licenseCanDistribute: 'Μπορεί να διανείμει',
  licenseCanSublicense: 'Μπορεί να χορηγήσει περαιτέρω άδεια',
  licenseCanHoldLiable: 'Μπορεί να θεωρηθεί υπεύθυνος',
  licenseCannotHoldLiable: 'Δεν μπορεί να θεωρηθεί υπεύθυνος',
  licenseMustIncludeCopyright: 'Πρέπει να περιλαμβάνει δικαιώματα πνευματικής ιδιοκτησίας',
  licenseMustIncludeLicense: 'Πρέπει να περιλαμβάνει άδεια',
  licenseFetchDetailsFailed: 'Αποτυχία λήψης λεπτομερειών άδειας',
  imageLightboxTitle: 'Εικόνες',
  imageLightBoxProgress: ':num από :total',
  nextImage: 'Επόμενη εικόνα',
  previousImage: 'Προηγούμενη εικόνα',
  screenshots: 'Στιγμιότυπα',
  reloadButtonLabel: 'Επαναφόρτωση',
  videoQuality: 'Ετικέτα ποιότητας βίντεο',
  videoQualityDescription: 'Αυτή η ετικέτα βοηθά τον χρήστη να αναγνωρίσει την τρέχουσα ποιότητα του βίντεο. Για παράδειγμα 1080p, 720p, HD ή Mobile',
  videoQualityDefaultLabel: 'Ποιότητα :index',
  noContentTypesAvailable: 'No content types are available',
  noContentTypesAvailableDesc: 'Your site is having difficulties connecting to H5P.org and listing the available content types.',
  contentTypeCacheOutdated: 'Content type list outdated',
  contentTypeCacheOutdatedDesc: 'Your site is having difficulties connecting to H5P.org to check for content type updates. You may not be able to update or install new content types.',
  tryAgain: 'Try again'
};

==> opigno_lms-7.x-1.41-core.tar.gz: opigno_lms-7.x-1.41/profiles/opigno_lms/modules/contrib/h5p/modules/h5peditor/h5peditor/language/el.js <==
H5PEditor.language.core = {
  missingTranslation: '[Λείπει μετάφραση :key]',
  loading: 'Φόρτωση, παρακαλούμε περιμένετε...',
  selectLibrary: 'Επιλέξτε τη βιβλιοθήκη την οποία θέλετε να χρησιμοποιήσετε για το περιεχόμενό σας.',
  unknownFieldPath: 'Δεν είναι δυνατή η εύρεση του ":path".',
  notImageField: 'Το ":path" δεν είναι εικόνα.',
  notImageOrDimensionsField: 'Το ":path" δεν είναι εικόνα ή πεδίο διαστάσεων.',
  requiredProperty: 'Η ιδιότητα :property απαιτείται, και πρέπει να έχει μια τιμή.',
  onlyNumbers: 'Η τιμή της ιδιότητας :property μπορεί να περιέχει μόνο αριθμούς.',
  exceedsMax: 'Η τιμή της ιδιότητας :property υπερβαίνει το μέγιστο :max.',
  listExceedsMax: 'Ο κατάλογος υπερβαίνει το μέγιστο των :max στοιχείων.',
  belowMin: 'Η τιμή της ιδιότητας :property είναι μικρότερη από το ελάχιστο :min.',
  listBelowMin: 'Η λίστα χρειάζεται τουλάχιστον :min στοιχεία για να λειτουργεί σωστά το περιεχόμενο.',
  outOfStep: 'Η τιμή της ιδιότητας :property μπορεί να αλλάξει μόνο σε :step βήματα.',
  add: 'Προσθήκη',
  addFile: 'Προσθήκη αρχείου',
  removeFile: 'Αφαίρεση αρχείου',
  confirmRemoval: 'Είστε σίγουροι οτι επιθυμείτε να αφαιρέσετε το :type;',
  removeImage: 'Αφαίρεση εικόνας',
  confirmImageRemoval: 'Αυτή η ενέργεια θα αφαιρέσει την εικόνα σας. Είστε σίγουροι οτι θέλετε να προχωρήσετε;',
  changeFile: 'Αλλαγή αρχείου',
  changeLibrary: 'Αλλαγή τύπου περιεχομένου;',
  semanticsError: 'Σφάλμα σημασιολογίας: :error',
  missingProperty: 'Το πεδίο :index υπολείπεται της ιδιότητας :property.',
  expandCollapse: 'Ανάπτυξη/Σύμπτυξη',
  addEntity: 'Προσθήκη :entity',
  tooLong: 'Η τιμή του πεδίου είναι πολύ μεγάλη, πρέπει να περιέχει :max γράμματα ή λιγότερα.',
  invalidFormat: 'Η τιμή του πεδίου περιέχει μια μη έγκυρη μορφή ή χαρακτήρες οι οποίοι απαγορεύονται.',
  confirmChangeLibrary: 'Κάνοντας αυτό θα χάσετε όλη την εργασία που έχει γίνει με τον τρέχοντα τύπο περιεχομένου. Είστε βέβαιοι ότι θέλετε να αλλάξετε τύπο περιεχομένου;',
  commonFields: 'Παραλλαγές κειμένου και μεταφράσεις',
  commonFieldsDescription: 'Εδώ μπορείτε να επεξεργαστείτε ρυθμίσεις ή να μεταφράσετε κείμενα τα οποία χρησιμοποιούνται σε αυτό το περιεχόμενο.',
  uploading: 'Μεταφόρτωση, παρακαλούμε περιμένετε...',
  noFollow: 'Δεν είναι δυνατή η παρακολούθηση του πεδίου ":path".',
  editCopyright: 'Επεξεργασία πνευματικών δικαιωμάτων',
  close: 'Κλείσιμο',
  tutorial: 'Μάθημα',
  editMode: 'Λειτουργία επεξεργασίας',
  listLabel: 'Λίστα',
  uploadError: 'Σφάλμα Μεταφόρτωσης Αρχείου',
  fileToLarge: 'Το αρχείο το οποίο προσπαθείτε να μεταφορτώσετε, ενδέχεται να είναι πολύ μεγάλο.',
  unknownFileUploadError: 'Άγνωστο σφάλμα μεταφόρτωσης αρχείου',
  noSemantics: 'Σφάλμα, δεν ήταν δυνατή η φόρτωση της φόρμας τύπου περιεχομένου.',
  editImage: 'Επεξεργασία εικόνας',
  saveLabel: 'Αποθήκευση',
  cancelLabel: 'ακύρωση',
  resetToOriginalLabel: 'Επαναφορά στο πρωτότυπο',
  loadingImageEditor: 'Φόρτωση επεξεργαστή εικόνας, παρακαλούμε περιμένετε...',
  selectFiletoUpload: 'Επιλέξτε αρχείο προς μεταφόρτωση',
  or: 'ή',
  enterAudioUrl: 'Εισαγάγετε διεύθυνση URL ήχου',
  enterVideoUrl: 'Εισαγάγετε διεύθυνση URL βίντεο ή σύνδεσμο YouTube',
  enterAudioTitle: 'Επικολλήστε σύνδεσμο ή άλλη διεύθυνση URL ήχου',
  enterVideoTitle: 'Επικολλήστε σύνδεσμο YouTube ή άλλη διεύθυνση URL βίντεο',
  uploadAudioTitle: 'Μεταφορτώστε αρχείο ήχου',
  uploadVideoTitle: 'Μεταφορτώστε αρχείο video',
  addVideoDescription: 'Το H5P υποστηρίζει όλες τις εξωτερικές πηγές βίντεο μορφοποιημένες ως mp4, webm ή ogv, όπως το Vimeo Pro, και έχει υποστήριξη για συνδέσμους YouTube.',
  insert: 'Εισαγωγή',
  cancel: 'Ακύρωση',
  height: 'ύψος',
  width: 'πλάτος',
  textField: 'πεδίο κειμένου',
  numberField: 'αριθμητικό πεδίο',
  orderItemUp: 'Ταξινόμηση στοιχείου προς τα επάνω',
  orderItemDown: 'Ταξινόμηση στοιχείου προς τα κάτω',
  removeItem: 'Αφαίρεση στοιχείου',
  hubPanelLabel: 'Επιλέξτε τύπο περιεχομένου',
  importantInstructions: 'Σημαντικές οδηγίες',
  showImportantInstructions: 'Εμφάνιση οδηγιών',
  hideImportantInstructions: 'Απόκρυψη σημαντικών οδηγιών',
  hide: 'Απόκρυψη',
  example: 'Παράδειγμα',
  createContentTabLabel: 'Δημιουργία Περιεχομένου',
  uploadTabLabel: 'Μεταφόρτωση',
  uploadPlaceholder: 'Δεν έχει επιλεγεί αρχείο',
  uploadInstructionsTitle: 'Μεταφορτώστε ένα αρχείο H5P.',
  uploadInstructionsContent: 'Μπορείτε να ξεκινήσετε με παραδείγματα από το <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Μεταφόρτωση αρχείου',
  uploadFileButtonChangeLabel: 'Αλλαγή αρχείου',
  uploadingThrobber: 'Γίνεται μεταφόρτωση...',
  uploadSuccess: ':title was successfully uploaded!',
  unableToInterpretError: 'Unable to interpret response.',
  unableToInterpretSolution: 'Please check your error log.',
  h5pFileWrongExtensionTitle: 'Δεν ήταν δυνατή η μεταφόρτωση του επιλεγμένου αρχείου',
  h5pFileWrongExtensionContent: 'Μόνο αρχεία με επέκταση .h5p επιτρέπονται.',
  h5pFileValidationFailedTitle: 'Δεν ήταν δυνατή η επικύρωση του αρχείου H5P.',
  h5pFileValidationFailedContent: 'Βεβαιωθείτε ότι το φορτωμένο H5P περιέχει έγκυρο περιεχόμενο H5P. Τα αρχεία H5P τα οποία περιέχουν μόνο βιβλιοθήκες, θα πρέπει να μεταφορτωθούν μέσω της σελίδας Βιβλιοθήκες H5P.',
  h5pFileUploadServerErrorTitle: 'Δεν ήταν δυνατή η μεταφόρτωση του αρχείου H5P',
  h5pFileUploadServerErrorContent: 'Προέκυψε ένα μη αναμενόμενο σφάλμα. Ελέγξτε το αρχείο σφαλμάτων του διακομιστή σας για περισσότερες λεπτομέρειες.',
  contentTypeSectionAll: 'All Content Types',
  searchResults: 'Search Results',
  contentTypeSearchFieldPlaceholder: 'Αναζητήστε Τύπους Περιεχομένου',
  contentTypeInstallButtonLabel: 'Εγκατάσταση',
  contentTypeInstallingButtonLabel: 'Εγκατάσταση',
  contentTypeUseButtonLabel: 'Χρήση',
  contentTypeDetailButtonLabel: 'Details',
  contentTypeUpdateButtonLabel: 'Ενημέρωση',
  contentTypeUpdatingButtonLabel: 'Ενημέρωση',
  contentTypeGetButtonLabel: 'Λήψη',
  contentTypeBackButtonLabel: 'Πίσω',
  contentTypeIconAltText: 'Εικονίδιο',
  contentTypeInstallSuccess: ':contentType εγκαταστάθηκε με επιτυχία!',
  contentTypeUpdateSuccess: ':contentType ενημερώθηκε με επιτυχία!',
  contentTypeInstallError: ':contentType δεν ήταν δυνατόν να εγκατασταθεί. Επικοινωνήστε με το διαχειριστή σας.',
  contentTypeLicensePanelTitle: 'Άδεια',
  contentTypeDemoButtonLabel: 'Δείγμα Περιεχομένου',
  numResults: ':num results',
  show: 'Show',
  recentlyUsedFirst: 'Recently Used First',
  popularFirst: 'Popular First',
  newestFirst: 'Newest First',
  aToZ: 'A to Z',
  noResultsFound: 'No results found',
  noResultsFoundDesc: 'There is no content type that matches your search criteria.',
  readMore: 'Διαβάστε περισσότερα',
  readLess: 'Διαβάστε λιγότερα',
  contentTypeOwner: 'Από :owner',
  contentTypeUnsupportedApiVersionTitle: 'Αυτός ο τύπος περιεχομένου απαιτεί νεότερη έκδοση',
  contentTypeUnsupportedApiVersionContent: 'Επικοινωνήστε με το διαχειριστή του συστήματός σας, για την παροχή των απαραίτητων ενημερώσεων',
  contentTypeUpdateAvailable: 'Υπάρχει διαθέσιμη ενημέρωση',
  contentTypeRestricted: 'Περιορισμένος τύπος περιεχομένου',
  contentTypeRestrictedDesc: 'Η χρήση αυτού του τύπου περιεχομένου έχει περιοριστεί από τον διαχειριστή.',
  contentTypeNotInstalled: 'Ο τύπος περιεχομένου δεν εγκαταστάθηκε',
  contentTypeNotInstalledDesc: 'Δεν έχετε άδεια για την εγκατάσταση τύπων περιεχομένου.',
  theContentType: 'τον τύπο περιεχομένου',
  currentMenuSelected: 'τρέχουσα επιλογή',
  errorCommunicatingHubTitle: 'Δεν είναι σε θέση να επικοινωνήσει με το διανομέα.',
  errorCommunicatingHubContent: 'Παρουσιάστηκε σφάλμα. Παρακαλούμε προσπαθήστε ξανα.',
  warningNoContentTypesInstalled: 'Δεν έχετε εγκατεστημένους τύπους περιεχομένου.',
  warningChangeBrowsingToSeeResults: 'Κάντε κλικ στο κουμπί <em>Όλα</em> για να λάβετε τη λίστα με όλους τους τύπους περιεχομένου τους οποίους μπορείτε να εγκαταστήσετε.',
  warningUpdateAvailableTitle: 'Μια νέα έκδοση του :contentType είναι διαθέσιμη.',
  warningUpdateAvailableBody: 'Ενημερώστε στην τελευταία έκδοση για βελτιωμένη εμπειρία χρήσης.',
  licenseDescription: 'Ορισμένα από τα χαρακτηριστικά αυτής της άδειας αναφέρονται παρακάτω. Κάντε κλικ στο παραπάνω εικονίδιο πληροφοριών για να διαβάσετε το πρωτότυπο κείμενο της άδειας χρήσης.',
  licenseModalTitle: 'Λεπτομέρειες Άδειας Χρήσης',
  licenseModalSubtitle: 'Επιλέξτε μια άδεια χρήσης για να δείτε πληροφορίες σχετικά με τη σωστή χρήση',
  licenseUnspecified: 'Απροσδιόριστο',
  licenseCanUseCommercially: 'Μπορεί να χρησιμοποιηθεί για εμπορικό σκοπό',
  licenseCanModify: 'Μπορεί να τροποποιηθεί',
  licenseCanDistribute: 'Μπορεί να διανείμει',
  licenseCanSublicense: 'Μπορεί να χορηγήσει περαιτέρω άδεια',
  licenseCanHoldLiable: 'Μπορεί να θεωρηθεί υπεύθυνος',
  licenseCannotHoldLiable: 'Δεν μπορεί να θεωρηθεί υπεύθυνος',
  licenseMustIncludeCopyright: 'Πρέπει να περιλαμβάνει δικαιώματα πνευματικής ιδιοκτησίας',
  licenseMustIncludeLicense: 'Πρέπει να περιλαμβάνει άδεια',
  licenseFetchDetailsFailed: 'Αποτυχία λήψης λεπτομερειών άδειας',
  imageLightboxTitle: 'Εικόνες',
  imageLightBoxProgress: ':num από :total',
  nextImage: 'Επόμενη εικόνα',
  previousImage: 'Προηγούμενη εικόνα',
  screenshots: 'Στιγμιότυπα',
  reloadButtonLabel: 'Επαναφόρτωση',
  videoQuality: 'Ετικέτα ποιότητας βίντεο',
  videoQualityDescription: 'Αυτή η ετικέτα βοηθά τον χρήστη να αναγνωρίσει την τρέχουσα ποιότητα του βίντεο. Για παράδειγμα 1080p, 720p, HD ή Mobile',
  videoQualityDefaultLabel: 'Ποιότητα :index',
  noContentTypesAvailable: 'No content types are available',
  noContentTypesAvailableDesc: 'Your site is having difficulties connecting to H5P.org and listing the available content types.',
  contentTypeCacheOutdated: 'Content type list outdated',
  contentTypeCacheOutdatedDesc: 'Your site is having difficulties connecting to H5P.org to check for content type updates. You may not be able to update or install new content types.',
  tryAgain: 'Try again',
  getHelp: 'Get help',
  untitled: 'Untitled :libraryTitle',
  title: 'Title',
  metadata: 'Metadata',
  addTitle: 'Add title',
  usedForSearchingReportsAndCopyrightInformation: 'Used for searching, reports and copyright information',
  metadataSharingAndLicensingInfo: 'Metadata (sharing and licensing info)',
  fillInTheFieldsBelow: 'Fill in the fields below',
  saveMetadata: 'Save metadata',
  addAuthor: 'Save author',
  confirmRemoveAuthor: 'Are you sure you would like to remove this author?',
  addNewChange: 'Add new change',
  confirmDeleteChangeLog: 'Are you sure you would like to delete this change log entry?',
  changelogDescription: 'Some licenses require that changes made to the original work, or derivatives are logged and displayed. You may log your changes here for licensing reasons or just to allow yourself and others to keep track of the changes made to this content.',
  logThisChange: 'Log this change',
  newChangeHasBeenLogged: 'New change has been logged',
  loggedChanges: 'Logged changes',
  noChangesHaveBeenLogged: 'No changes have been logged',
  errorHeader: 'An error occured',
  errorCalculatingMaxScore: 'Could not calculate the max score for this content. The max score is assumed to be 0. Contact your administrator if this isn’t correct.',
  maxScoreSemanticsMissing: 'Could not find the expected semantics in the content.',
  copyButton: 'Copy',
  copiedButton: 'Copied',
  pasteButton: 'Paste',
  pasteAndReplaceButton: 'Paste & Replace',
  pasteContent: 'Replace Content',
  confirmPasteContent: 'By doing this you will replace the current content with the content from your clipboard. The current content will be lost. Are you sure you wish to continue?',
  confirmPasteButtonText: 'Replace content',
  copyToClipboard: 'Copy H5P content to the clipboard',
  copiedToClipboard: 'Content is copied to the clipboard',
  pasteFromClipboard: 'Paste H5P content from the clipboard',
  pasteAndReplaceFromClipboard: 'Replace existing content with H5P Content from the clipboard',
  pasteNoContent: 'No H5P content on the clipboard',
  pasteError: 'Cannot paste from clipboard',
  pasteContentNotSupported: 'The content you’re trying to paste is not supported in this context',
  pasteTooOld: 'The content you’re trying to paste is of a lower version (:clip) than what is supported in this context (:local), if possible try to have the content you want to paste upgraded, copy it again and try pasting it here.',
  pasteTooNew: 'The content you’re trying to paste is of a higher version (:clip) than what is supported in this context (:local), if possible try to have this content upgraded first, and then try pasting the content here again.',
  ok: 'OK',
};
